@@ -44,7 +44,7 @@ $lang = array_merge($lang, array(
 	'DEFAULT_LANGUAGE'				=> 'Limba standard',
 	'DEFAULT_STYLE'					=> 'Stil standard',
 	'DISABLE_BOARD'					=> 'Dezactivează forum',
-	'DISABLE_BOARD_EXPLAIN'			=> 'Aceasta operaţie va face forumul indisponibil pentru utilizatori. De asemenea, dacă doriţi puteţi specifica un mesaj scurt (255 caractere) ce va fi afişat.',
+	'DISABLE_BOARD_EXPLAIN'			=> 'Aceasta operaţie va face forumul indisponibil pentru utilizatorii ce nu sunt administratori sau moderatori. De asemenea, dacă doriţi puteţi specifica un mesaj scurt (255 caractere) ce va fi afişat.',
 	'OVERRIDE_STYLE'				=> 'Suprascrie stilul utilizatorului',
 	'OVERRIDE_STYLE_EXPLAIN'		=> 'Înlocuieşte stilul utilizatorului cu cel standard.',
 	'SITE_DESC'						=> 'Descriere site',
@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'				=> 'Fusul orar al vizitatorului',
 	'SYSTEM_TIMEZONE_EXPLAIN'         => 'Fusul orar folosit pentru afişarea timpului utilizatorilor ce nu sunt autentificaţi (vizitatori, roboţi). Utilizatorii autentificaţi specifică fusul orar în timpul înregistrării şi-l pot modifica prin panoul de control al utilizatorului.',
 	'WARNINGS_EXPIRE'				=> 'Durată avertisment',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Numărul zilelor ce trebuie să treacă înainte ca avertismentul să expire automat din înregistrarea unui utilizator. Setați 0 pentru a face avertismentele permanente',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Numărul zilelor ce trebuie să treacă înainte ca un avertisment să expire automat din înregistrarea unui utilizator. Setați 0 pentru a face avertismentele permanente',
 ));
 
 // Board Features
@@ -105,7 +105,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_GALLERY_PATH'			=> 'Cale galerie avatar',
 	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Calea din directorul rădăcină phpBB pentru imagini preîncărcate, de exemplu <samp>images/avatars/gallery</samp>',
 	'AVATAR_STORAGE_PATH'			=> 'Cale stocare avatar',
-	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Calea din directorul rădăcină phpBB, de exemplu. <samp>images/avatars/upload</samp>',
+	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Calea din directorul rădăcină phpBB, de exemplu. <samp>images/avatars/upload</samp>.<br />Funționalitatea de încărcare a imaginii asociate (avatar) <strong>nu va fi disponibilă</strong> dacă nu se poate scrie în această locație.',
 	'MAX_AVATAR_SIZE'				=> 'Dimensiunile maxime ale avatarului',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Lăţime x Înălţime în pixeli',
 	'MAX_FILESIZE'					=> 'Dimensiunile maxime ale fişierului avatar',
@@ -135,7 +135,7 @@ $lang = array_merge($lang, array(
 	'BOXES_MAX_EXPLAIN'			=> 'Standard, utilizatorii pot crea atât de multe directoare personale pentru mesajele private.',
 	'ENABLE_PM_ICONS'			=> 'Permite folosirea iconiţelor pentru subiect în mesajele private',
 	'FULL_FOLDER_ACTION'		=> 'Acţiunea standard pentru director plin',
-	'FULL_FOLDER_ACTION_EXPLAIN'=> 'Acţiunea standard ce va fi luată dacă directorul utilizatorului este plin, presupunând că acţiunea directorului utilizatorului, dacă este setată la toate, nu este aplicabilă. Singura excepţie este pentru directorul “Mesaje trimise” unde acţiunea iniţială este mereu aceea de a şterge mesajele vechi.',
+	'FULL_FOLDER_ACTION_EXPLAIN'=> 'Acţiunea standard ce va fi luată dacă directorul utilizatorului este plin, presupunând că opțiunea utilizatorului setată pentru toate directoarele, nu este aplicabilă. Singura excepţie este pentru directorul „Mesaje trimise” unde acţiunea iniţială este mereu aceea de a şterge mesajele vechi.',
 	'HOLD_NEW_MESSAGES'			=> 'Păstrează mesajele noi',
 	'PM_EDIT_TIME'				=> 'Limita timpului de modificare',
 	'PM_EDIT_TIME_EXPLAIN'		=> 'Limitează timpul disponibil pentru a modifica mesajele private care încă nu au fost trimise. Specificând valoarea 0, această operaţie va fi dezactivată.',
@@ -263,21 +263,21 @@ $lang = array_merge($lang, array(
 	'ACP_FEED_LIMIT_EXPLAIN'			=> 'Numărul maxim de elemente ale fluxului ce vor fi afişate.',
 
 	'ACP_FEED_OVERALL'			=> 'Activare flux din toate subiectele',
-	'ACP_FEED_OVERALL_EXPLAIN'	=> 'Activează fluxul “Toate Subiectele”',
+	'ACP_FEED_OVERALL_EXPLAIN'	=> 'Activează fluxul „Toate Subiectele”',
 	'ACP_FEED_FORUM'					=> 'Activare fluxuri pe fiecare forum',
 	'ACP_FEED_FORUM_EXPLAIN'			=> 'Mesajele noi din forum.',
 	'ACP_FEED_TOPIC'					=> 'Activare fluxuri pe fiecare subiect',
 	'ACP_FEED_TOPIC_EXPLAIN'			=> 'Mesajele noi din subiecte.',
 	
 	'ACP_FEED_TOPICS_NEW'				=> 'Activează fluxuri pentru subiectele noi',
-	'ACP_FEED_TOPICS_NEW_EXPLAIN'		=> 'Activează fluxul “Subiecte noi” ce afişează ultimele subiecte create incluzând primul mesaj.',
+	'ACP_FEED_TOPICS_NEW_EXPLAIN'		=> 'Activează fluxul „Subiecte noi” ce afişează ultimele subiecte create incluzând primul mesaj.',
 	'ACP_FEED_TOPICS_ACTIVE'			=> 'Activează fluxul subiectelor active',
-	'ACP_FEED_TOPICS_ACTIVE_EXPLAIN'	=> 'Activează fluxul “Subiecte active” ce afişează ultimele subiecte active incluzând ultimul mesaj.',
+	'ACP_FEED_TOPICS_ACTIVE_EXPLAIN'	=> 'Activează fluxul „Subiecte active” ce afişează ultimele subiecte active incluzând ultimul mesaj.',
 	'ACP_FEED_NEWS'						=> 'Fluxuri de ştiri',
 	'ACP_FEED_NEWS_EXPLAIN'				=> 'Extrage primul mesaj din aceste forumuri. Nu selectaţi un forum pentru a dezactiva fluxul de ştiri.<br />Selectaţi mai multe forumuri ţinând apăsată tasta <samp>CTRL</samp> şi făcând click.',
 
   'ACP_FEED_OVERALL_FORUMS'			=> 'Activare fluxuri din toate forumurile',
-	'ACP_FEED_OVERALL_FORUMS_EXPLAIN'	=> 'Activează fluxul “Toate forumurile” ce afişează o listă cu forumurile.',
+	'ACP_FEED_OVERALL_FORUMS_EXPLAIN'	=> 'Activează fluxul „Toate forumurile” ce afişează o listă cu forumurile.',
 	
 	'ACP_FEED_HTTP_AUTH'				=> 'Permite autentificare HTTP',
 	'ACP_FEED_HTTP_AUTH_EXPLAIN'		=> 'Activează autentificarea HTTP ce permite utilizatorilor să primească informaţii ce sunt ascunse vizitatorilor prin adăugarea parametrului <samp>auth=http</samp> în URL-ul fluxului. Reţineţi că anumite setări PHP necesită mai multe modificări în fişierul .htaccess. Instrucţiunile pot fi găsite în acel fişier.',
@@ -345,7 +345,7 @@ $lang = array_merge($lang, array(
 	'COOKIE_SECURE'				=> 'Securizare cookie',
 	'COOKIE_SECURE_EXPLAIN'		=> 'Dacă serverul propriu rulează via SSL atunci setaţi această opţiune pentru a o activa, altfel rămâne ca dezactivată. Având această opţiune activată şi serverul propriu nu rulează via SSL, atunci vor apărea erori de server în timpul redirecţionărilor.',
 	'ONLINE_LENGTH'				=> 'Limită timp utilizatori online',
-	'ONLINE_LENGTH_EXPLAIN'		=> 'Numărul de minute după care utilizatorii inactivi nu vor mai apărea în secţiunea "Cine este conectat". Cu cât este mai mare valoarea, cu atât este lungă procesarea necesară pentru a genera această listă.',
+	'ONLINE_LENGTH_EXPLAIN'		=> 'Numărul de minute după care utilizatorii inactivi nu vor mai apărea în secţiunea „Cine este conectat”. Cu cât este mai mare valoarea, cu atât este lungă procesarea necesară pentru a genera această listă.',
 	'SESSION_LENGTH'			=> 'Durată sesiune',
 	'SESSION_LENGTH_EXPLAIN'	=> 'Sesiunea va expira după acest timp, în secunde.',
 ));
@@ -374,8 +374,8 @@ $lang = array_merge($lang, array(
 	'YES_MODERATORS'				=> 'Permite afişarea moderatorilor',
 	'YES_ONLINE'					=> 'Permite listarea utilizatorilor conectaţi',
 	'YES_ONLINE_EXPLAIN'			=> 'Afişează informaţiile utilizatorilor conectaţi în index, forum şi paginile subiectelor.',
-	'YES_ONLINE_GUESTS'				=> 'Activează afişarea vizitatorilor conectaţi în secţiunea "Cine este conectat"',
-	'YES_ONLINE_GUESTS_EXPLAIN'		=> 'Permite afişarea informaţiilor vizitatorilor conectaţi în "Cine este conectat".',
+	'YES_ONLINE_GUESTS'				=> 'Activează afişarea vizitatorilor conectaţi în secţiunea „Cine este conectat”',
+	'YES_ONLINE_GUESTS_EXPLAIN'		=> 'Permite afişarea informaţiilor vizitatorilor conectaţi în „Cine este conectat”.',
 	'YES_ONLINE_TRACK'				=> 'Activează afişarea informaţiilor utilizatorilor conectaţi/neconectaţi',
 	'YES_ONLINE_TRACK_EXPLAIN'		=> 'Afişează informaţiile online pentru utilizatori în profiluri şi în paginile subiectului.',
 	'YES_POST_MARKING'				=> 'Activează subiectele punctate',
@@ -421,7 +421,7 @@ $lang = array_merge($lang, array(
 	'ENABLE_GZIP'				=> 'Activează compresia GZip',
 	'ENABLE_GZIP_EXPLAIN'		=> 'Conţinutul generat va fi compresat înainte de a fi trimis utilizatorului. Această operaţie poate reduce traficul reţelei, dar de asemenea va mări gradul de folosire al procesorului pe server şi pe partea clientului. Pentru a funcţiona, trebuie ca extensia PHP zlib să fie încărcată.',
 	'FORCE_SERVER_VARS'			=> 'Forţează setările URL pentru server',
-	'FORCE_SERVER_VARS_EXPLAIN'	=> 'Dacă alegeţi "Da", setările serverului definite vor fi folosite în locul determinării automate a valorilor.',
+	'FORCE_SERVER_VARS_EXPLAIN' => 'Dacă alegeţi „Da”,  în locul valorii determinate automat, serverul va fi setat așa cum l-ați definit.',
 	'ICONS_PATH'				=> 'Cale stocare iconiţe mesaj',
 	'ICONS_PATH_EXPLAIN'		=> 'Calea din directorul rădăcină al phpBB, de exemplu <samp>images/icons</samp>',
 	'PATH_SETTINGS'				=> 'Setări cale',
@@ -512,7 +512,7 @@ $lang = array_merge($lang, array(
 	'EMAIL_SIG'						=> 'Semnătură e-mail',
 	'EMAIL_SIG_EXPLAIN'				=> 'Acest text va fi ataşat tuturor e-mail-urilor trimise de către forum.',
 	'ENABLE_EMAIL'					=> 'Activează posibilitatea forumulului să poată trimite e-mailuri',
-	'ENABLE_EMAIL_EXPLAIN'			=> 'Dacă această opţiune este setată ca fiind dezactivată, niciun e-mail nu va fi trimis de către forum. <em>Reţineţi că setările de activare ale contului de utilizator şi administrator impun ca această setare să fie activată. Dacă în secţiunea setărilor activării se foloseşte activarea de către “Utilizator” sau “Administrator”, dezactivând această setare nu va mai necesita activarea conturilor noi.</em>',
+	'ENABLE_EMAIL_EXPLAIN'			=> 'Dacă această opţiune este setată ca fiind dezactivată, niciun e-mail nu va fi trimis de către forum. <em>Reţineţi că setările de activare ale contului de utilizator şi administrator impun ca această setare să fie activată. Dacă în secţiunea setărilor activării se foloseşte activarea de către „Utilizator” sau „Administrator”, dezactivând această setare nu va mai necesita activarea conturilor noi.</em>',
 	'SMTP_AUTH_METHOD'				=> 'Metoda de autentificare pentru SMTP',
 	'SMTP_AUTH_METHOD_EXPLAIN'		=> 'Folosită doar dacă un nume de utilizator/parolă este setat, întrebaţi provider-ul dacă nu sunteţi sigur ce metodă să folosiţi.',
 	'SMTP_CRAM_MD5'					=> 'CRAM-MD5',
@@ -529,7 +529,7 @@ $lang = array_merge($lang, array(
 	'SMTP_USERNAME'					=> 'Nume de utilizator SMTP',
 	'SMTP_USERNAME_EXPLAIN'			=> 'Specificaţi un nume de utilizator doar dacă serverul SMTP îl cere.',
 	'USE_SMTP'						=> 'Foloseşte serverul SMTP pentru e-mail-uri',
-	'USE_SMTP_EXPLAIN'				=> 'Selectaţi “Da” dacă doriţi să trimiteţi e-mail-uri prin intermediul unui server anume în locul funcţiei locale de mesagerie.',
+	'USE_SMTP_EXPLAIN'				=> 'Selectaţi „Da” dacă doriţi să trimiteţi e-mail-uri prin intermediul unui server anume în locul funcţiei locale de mesagerie.',
 ));
 
 // Jabber settings
