@@ -38,7 +38,7 @@ if (empty($lang) || !is_array($lang))
 // Common
 $lang = array_merge($lang, array(
 	'ACP_ADMINISTRATORS'		=> 'Administratori',
-	'ACP_ADMIN_LOGS'			=> 'Log administrator',
+	'ACP_ADMIN_LOGS'			=> 'Jurnal administrator',
 	'ACP_ADMIN_ROLES'			=> 'Roluri administrator',
 	'ACP_ATTACHMENTS'			=> 'Fişiere ataşate',
 	'ACP_ATTACHMENT_SETTINGS'	=> 'Configurări fişiere ataşate',
@@ -46,11 +46,11 @@ $lang = array_merge($lang, array(
 	'ACP_AUTOMATION'			=> 'Automatizare',
 	'ACP_AVATAR_SETTINGS'		=> 'Configurări imagini asociate',
 
-	'ACP_BACKUP'				=> 'Salvare (Backup)',
-	'ACP_BAN'					=> 'Banare',
-	'ACP_BAN_EMAILS'			=> 'Banare conturi e-mail',
-	'ACP_BAN_IPS'				=> 'Banare IP-uri',
-	'ACP_BAN_USERNAMES'			=> 'Banare nume utilizatori',
+	'ACP_BACKUP'				=> 'Copie de rezervă',
+	'ACP_BAN'					=> 'Interzicere',
+	'ACP_BAN_EMAILS'			=> 'Interzicere conturi e-mail',
+	'ACP_BAN_IPS'				=> 'Interzicere IP-uri',
+	'ACP_BAN_USERNAMES'			=> 'Interzicere utilizatori',
 	'ACP_BBCODES'				=> 'CoduriBB',
 	'ACP_BOARD_CONFIGURATION'	=> 'Configurare forum',
 	'ACP_BOARD_FEATURES'		=> 'Caracteristici forum',
@@ -61,7 +61,7 @@ $lang = array_merge($lang, array(
 	'ACP_CAPTCHA'				=> 'CAPTCHA',
 
 	'ACP_CAT_DATABASE'			=> 'Baza de date',
-	'ACP_CAT_DOT_MODS'			=> '.Mod-uri',
+	'ACP_CAT_DOT_MODS'			=> 'MODificări',
 	'ACP_CAT_FORUMS'			=> 'Forumuri',
 	'ACP_CAT_GENERAL'			=> 'General',
 	'ACP_CAT_MAINTENANCE'		=> 'Întreţinere',
@@ -73,7 +73,7 @@ $lang = array_merge($lang, array(
 	'ACP_CAT_USERS'				=> 'Utilizatori',
 	'ACP_CLIENT_COMMUNICATION'	=> 'Comunicaţii client',
 	'ACP_COOKIE_SETTINGS'		=> 'Configurări cookie',
-	'ACP_CRITICAL_LOGS'			=> 'Log erori',
+	'ACP_CRITICAL_LOGS'			=> 'Jurnal erori',
 	'ACP_CUSTOM_PROFILE_FIELDS'	=> 'Câmpuri profil personalizabil',
 	
 	'ACP_DATABASE'				=> 'Administrare bază de date',
@@ -84,7 +84,7 @@ $lang = array_merge($lang, array(
 	'ACP_EXTENSION_GROUPS'		=> 'Administrare extensii grupuri',
 	
 	'ACP_FORUM_BASED_PERMISSIONS'	=> 'Permisiuni bazate pe forum',
-	'ACP_FORUM_LOGS'				=> 'Loguri forum',
+	'ACP_FORUM_LOGS'				=> 'Jurnale forum',
 	'ACP_FORUM_MANAGEMENT'			=> 'Administrare forum',
 	'ACP_FORUM_MODERATORS'			=> 'Moderatori forum',
 	'ACP_FORUM_PERMISSIONS'			=> 'Permisiuni forum',
@@ -112,7 +112,7 @@ $lang = array_merge($lang, array(
 	'ACP_LANGUAGE'				=> 'Administrare limbă',
 	'ACP_LANGUAGE_PACKS'		=> 'Pachete limbă',
 	'ACP_LOAD_SETTINGS'			=> 'Configurări încărcare',
-	'ACP_LOGGING'				=> 'Logare',
+	'ACP_LOGGING'				=> 'Autentificare',
 	
 	'ACP_MAIN'					=> 'Panoul administratorului',
 	'ACP_MANAGE_EXTENSIONS'		=> 'Administrare extensii',
@@ -124,7 +124,7 @@ $lang = array_merge($lang, array(
 	'ACP_MESSAGES'				=> 'Mesaje',
 	'ACP_MESSAGE_SETTINGS'		=> 'Configurări mesaje private',
 	'ACP_MODULE_MANAGEMENT'		=> 'Modul administrare',
-	'ACP_MOD_LOGS'				=> 'Log moderator',
+	'ACP_MOD_LOGS'				=> 'Jurnal moderator',
 	'ACP_MOD_ROLES'				=> 'Roluri moderator',
 	
 	'ACP_NO_ITEMS'				=> 'Nu există încă un element.',
@@ -171,11 +171,11 @@ $lang = array_merge($lang, array(
 	
 	'ACP_UPDATE'					=> 'Actualizare',
 	'ACP_USERS_FORUM_PERMISSIONS'	=> 'Permisiuni forum pentru utilizatori',
-	'ACP_USERS_LOGS'				=> 'Log utilizatori',
+	'ACP_USERS_LOGS'				=> 'Jurnal utilizatori',
 	'ACP_USERS_PERMISSIONS'			=> 'Permisiuni utilizatori',
 	'ACP_USER_ATTACH'				=> 'Fişiere ataşate',
 	'ACP_USER_AVATAR'				=> 'Imagine asociată (avatar)',
-	'ACP_USER_FEEDBACK'				=> 'Feedback',
+	'ACP_USER_FEEDBACK'				=> 'Părere',
 	'ACP_USER_GROUPS'				=> 'Grupuri',
 	'ACP_USER_MANAGEMENT'			=> 'Administrare utilizator',
 	'ACP_USER_OVERVIEW'				=> 'Privire generală',
@@ -216,9 +216,9 @@ $lang = array_merge($lang, array(
 	'CONFIG_UPDATED'		=> 'Configurarea a fost actualizată cu succes.',
 
 	'DEACTIVATE'				=> 'Dezactivează',
-	'DIRECTORY_DOES_NOT_EXIST'	=> 'Calea introdusă “%s” nu există.',
-	'DIRECTORY_NOT_DIR'			=> 'Calea introdusă “%s” nu este un director.',
-	'DIRECTORY_NOT_WRITABLE'	=> 'Calea introdusă “%s” nu se poate scrie.',
+	'DIRECTORY_DOES_NOT_EXIST'	=> 'Calea introdusă „%s” nu există.',
+	'DIRECTORY_NOT_DIR'			=> 'Calea introdusă „%s” nu este un director.',
+	'DIRECTORY_NOT_WRITABLE'	=> 'Calea introdusă „%s” nu se poate scrie.',
 	'DISABLE'					=> 'Dezactivează',
 	'DOWNLOAD'					=> 'Descarcă',
 	'DOWNLOAD_AS'				=> 'Descarcă ca',
@@ -275,10 +275,10 @@ $lang = array_merge($lang, array(
 	'SELECT_ANONYMOUS'		=> 'Selectează utilizatorul anonim',
 	'SELECT_OPTION'			=> 'Selectează opţiune',
 	
-	'SETTING_TOO_LOW'		=> 'Valoarea specificată pentru variabila “%1$s” este prea mică. Valoarea minimă admisă este %2$d.',
-	'SETTING_TOO_BIG'		=> 'Valoarea specificată pentru variabila “%1$s” este prea mare. Valoarea maximă admisă este %2$d.',	
-	'SETTING_TOO_LONG'		=> 'Valoarea specificată pentru variabila “%1$s” este prea lungă. Lungimea maximă admisă este %2$d.',
-	'SETTING_TOO_SHORT'		=> 'Valoarea specificată pentru variabila “%1$s” prea scurtă. Lungimea minimă admisă este %2$d.',
+	'SETTING_TOO_LOW'		=> 'Valoarea specificată pentru variabila „%1$s” este prea mică. Valoarea minimă admisă este %2$d.',
+	'SETTING_TOO_BIG'		=> 'Valoarea specificată pentru variabila „%1$s” este prea mare. Valoarea maximă admisă este %2$d.',	
+	'SETTING_TOO_LONG'		=> 'Valoarea specificată pentru variabila „%1$s” este prea lungă. Lungimea maximă admisă este %2$d.',
+	'SETTING_TOO_SHORT'		=> 'Valoarea specificată pentru variabila „%1$s” prea scurtă. Lungimea minimă admisă este %2$d.',
 	'SHOW_ALL_OPERATIONS'	=> 'Arată toate operaţiile',
 
 	'UCP'					=> 'Panoul utilizatorului',
@@ -290,33 +290,33 @@ $lang = array_merge($lang, array(
 
 // PHP info
 $lang = array_merge($lang, array(
-	'ACP_PHP_INFO_EXPLAIN'	=> 'Această pagină listează informaţiile versiunii de PHP instalate pe acest server. Include detaliile modulelor încărcate, variabilelor disponibile şi setările standard. Această informaţie poate fi de ajutor pentru diagnosticarea problemelor. Vă rog, fiţi conştient că unele companii de hosting vor limita ce informaţii să afişeze din motive de securitate. Sunteţi avizat să nu daţi mai departe detaliile acestei pagini, exceptând când sunteţi întrebat de un <a href="http://www.phpbb.com/about/team/">membru oficial al echipei de suport</a>.',
+	'ACP_PHP_INFO_EXPLAIN'	=> 'Această pagină listează informaţiile versiunii de PHP instalate pe acest server. Include detaliile modulelor încărcate, variabilelor disponibile şi setările standard. Această informaţie poate fi de ajutor pentru diagnosticarea problemelor. Vă rog, fiţi conştient că unele companii de hosting vor limita ce informaţii să afişeze din motive de securitate. Sunteţi avizat să nu daţi mai departe detaliile acestei pagini, exceptând când sunteţi întrebat de un <a href="https://www.phpbb.com/about/team/">membru oficial al echipei de suport</a>.',
 
 	'NO_PHPINFO_AVAILABLE'	=> 'Informaţiile despre configuraţia PHP nu pot fi determinate. Phpinfo() a fost dezactivat din motive de securitate.',
 ));
 
 // Logs
 $lang = array_merge($lang, array(
-	'ACP_ADMIN_LOGS_EXPLAIN'	=> 'Aici vedeţi listate toate acţiunile efectuate de administratorii forumului. Le puteţi sorta după nume de utilizator, după dată, IP sau acţiune. Dacă aveţi permisiunile necesare, puteţi să ştergeţi operaţiunile individuale sau tot log-ul.',
-	'ACP_CRITICAL_LOGS_EXPLAIN'	=> 'Aici vedeţi toate acţiunile efectuate de către forum. Acest log vă inştiinţează cu informaţii pe care le puteţi folosi la rezolvarea problemelor specifice, de exemplu netrimiterea e-mail-urilor. Le puteţi sorta după nume utilizator, dată, IP sau acţiune. Dacă aveţi permisiunile necesare, puteţi să ştergeţi operaţiunile individuale sau tot log-ul.',
-	'ACP_MOD_LOGS_EXPLAIN'		=> 'Aici vedeţi toate acţiunile efectuate de către moderatori în forumuri, subiecte şi mesaje, de asemenea acţiunile efectuate asupra utilizatorilor, inclusiv banarea. Le poţi sorta după nume utilizator, dată, IP sau acţiune. Dacă aveţi permisiunile necesare, puteţi să ştergeţi operaţiunile individuale sau tot log-ul.',
-	'ACP_USERS_LOGS_EXPLAIN'	=> 'Aici vedeţi toate acţiunile realizate de către utilizatori sau asupra utilizatorilor (raportări, avertismente şi note user).',
+	'ACP_ADMIN_LOGS_EXPLAIN'	=> 'Aici vedeţi listate toate acţiunile efectuate de administratorii forumului. Le puteţi sorta după nume de utilizator, după dată, IP sau acţiune. Dacă aveţi permisiunile necesare, puteţi să ştergeţi operaţiunile individuale sau tot jurnalul.',
+	'ACP_CRITICAL_LOGS_EXPLAIN'	=> 'Aici vedeţi toate acţiunile efectuate de către forum. Acest jurnal vă înştiinţează cu informaţii pe care le puteţi folosi la rezolvarea problemelor specifice, de exemplu netrimiterea e-mail-urilor. Le puteţi sorta după nume utilizator, dată, IP sau acţiune. Dacă aveţi permisiunile necesare, puteţi să ştergeţi operaţiunile individuale sau tot jurnalul.',
+	'ACP_MOD_LOGS_EXPLAIN'		=> 'Aici vedeţi toate acţiunile efectuate de către moderatori în forumuri, subiecte şi mesaje, de asemenea acţiunile efectuate asupra utilizatorilor, inclusiv interzicerea. Le puteți sorta după nume utilizator, dată, IP sau acţiune. Dacă aveţi permisiunile necesare, puteţi să ştergeţi operaţiunile individuale sau tot jurnalul.',
+	'ACP_USERS_LOGS_EXPLAIN'	=> 'Aici vedeţi toate acţiunile realizate de către utilizatori sau asupra utilizatorilor (raportări, avertismente şi note utilizator).',
 	'ALL_ENTRIES'				=> 'Toate intrările',
 
 	'DISPLAY_LOG'	=> 'Afişează intrările de la anteriorul',
 
-	'NO_ENTRIES'	=> 'Nicio informaţie în log pentru această perioadă.',
+	'NO_ENTRIES'	=> 'Nicio informaţie în jurnal pentru această perioadă.',
 
 	'SORT_IP'		=> 'Adresă IP',
 	'SORT_DATE'		=> 'Dată',
-	'SORT_ACTION'	=> 'Acţiune log',
+	'SORT_ACTION'	=> 'Acţiune jurnal',
 ));
 
 // Index page
 $lang = array_merge($lang, array(
-	'ADMIN_INTRO'				=> 'Mulţumim că aţi ales phpBB ca soluţie pentru forumul dumneavoastră. Această pagină vă va da o scurtă privire de ansamblu a tuturor statisticilor forumului dumneavoastră. Link-urile de pe partea stângă a paginii vă permit să controlaţi orice aspect a experienţei dumneavoastră pe forum. Fiecare pagină va avea instrucţiuni despre modul de folosire a opţiunilor.',
-	'ADMIN_LOG'					=> 'Log cu acţiunile administratorilor',
-	'ADMIN_LOG_INDEX_EXPLAIN'	=> 'Aici vedeţi ultimele cinci acţiuni realizate de către administratori. Pentru a vedea toate acţiunile realizate de către aceştia, accesaţi articolul adecvat din meniu sau urmaţi link-ul de mai jos.',
+	'ADMIN_INTRO'				=> 'Mulţumim că aţi ales phpBB ca soluţie pentru forumul dumneavoastră. Această pagină vă va da o scurtă privire de ansamblu a tuturor statisticilor forumului dumneavoastră. Legăturile de pe partea stângă a paginii vă permit să controlaţi orice aspect a experienţei dumneavoastră pe forum. Fiecare pagină va avea instrucţiuni despre modul de folosire a opţiunilor.',
+	'ADMIN_LOG'					=> 'Jurnal cu acţiunile administratorilor',
+	'ADMIN_LOG_INDEX_EXPLAIN'	=> 'Aici vedeţi ultimele cinci acţiuni realizate de către administratori. Pentru a vedea toate acţiunile realizate de către aceştia, accesaţi articolul adecvat din meniu sau urmaţi legătura de mai jos.',
 	'AVATAR_DIR_SIZE'			=> 'Dimensiunile directorului de imagini asociate (avatare)',
 
 	'BOARD_STARTED'		=> 'Forum din data de',
@@ -456,8 +456,8 @@ $lang = array_merge($lang, array(
 	'LOG_ACL_TRANSFER_PERMISSIONS'		=> '<strong>Permisiuni transferate de la</strong><br />» %s',
 	'LOG_ACL_RESTORE_PERMISSIONS'		=> '<strong>Propriile permisiuni restaurate după ce s-au folosit permisiunile de la</strong><br />» %s',
 	
-	'LOG_ADMIN_AUTH_FAIL'		=> '<strong>Încercare de logare administrativă eşuată</strong>',
-	'LOG_ADMIN_AUTH_SUCCESS'	=> '<strong>Logare administrativă cu succes</strong>',
+	'LOG_ADMIN_AUTH_FAIL'		=> '<strong>Încercare de autentificare administrativă eşuată</strong>',
+	'LOG_ADMIN_AUTH_SUCCESS'	=> '<strong>Autentificare administrativă cu succes</strong>',
 	
 	'LOG_ATTACHMENTS_DELETED'	=> '<strong>Fişiere ataşate ale utilizatorului eliminate</strong><br />» %s',
 
@@ -470,15 +470,15 @@ $lang = array_merge($lang, array(
 	'LOG_ATTACH_FILEUPLOAD'		=> '<strong>Fişier fără legătură încărcat la mesaj</strong><br />» ID %1$d - %2$s',
 	'LOG_ATTACH_ORPHAN_DEL'		=> '<strong>Fişiere fără legătură şterse</strong><br />» %s',
 
-	'LOG_BAN_EXCLUDE_USER'	=> '<strong>Utilizator exclus de la ban</strong> pentru motiv “<em>%1$s</em>”<br />» %2$s ',
-	'LOG_BAN_EXCLUDE_IP'	=> '<strong>IP exclus de la ban</strong> pentru motiv “<em>%1$s</em>”<br />» %2$s ',
-	'LOG_BAN_EXCLUDE_EMAIL' => '<strong>E-mail exclus de la ban</strong> pentru motiv “<em>%1$s</em>”<br />» %2$s ',
-	'LOG_BAN_USER'			=> '<strong>Utilizator banat</strong> pentru motiv “<em>%1$s</em>”<br />» %2$s ',
-	'LOG_BAN_IP'			=> '<strong>IP banat</strong> pentru motiv “<em>%1$s</em>”<br />» %2$s',
-	'LOG_BAN_EMAIL'			=> '<strong>E-mail banat</strong> pentru motiv “<em>%1$s</em>”<br />» %2$s',
-	'LOG_UNBAN_USER'		=> '<strong>Utilizator debanat</strong><br />» %s',
-	'LOG_UNBAN_IP'			=> '<strong>IP debanat</strong><br />» %s',
-	'LOG_UNBAN_EMAIL'		=> '<strong>E-mail debanat</strong><br />» %s',
+	'LOG_BAN_EXCLUDE_USER'	=> '<strong>Utilizator exclus de la interziceri</strong> pentru motiv „<em>%1$s</em>”<br />» %2$s ',
+	'LOG_BAN_EXCLUDE_IP'	=> '<strong>IP exclus de la interziceri</strong> pentru motiv „<em>%1$s</em>”<br />» %2$s ',
+	'LOG_BAN_EXCLUDE_EMAIL' => '<strong>E-mail exclus de la interziceri</strong> pentru motiv „<em>%1$s</em>”<br />» %2$s ',
+	'LOG_BAN_USER'			=> '<strong>Utilizator interzis</strong> pentru motiv „<em>%1$s</em>”<br />» %2$s ',
+	'LOG_BAN_IP'			=> '<strong>IP interzis</strong> pentru motiv „<em>%1$s</em>”<br />» %2$s',
+	'LOG_BAN_EMAIL'			=> '<strong>E-mail interzis</strong> pentru motiv „<em>%1$s</em>”<br />» %2$s',
+	'LOG_UNBAN_USER'		=> '<strong>Interdicție utilizator eliminată</strong><br />» %s',
+	'LOG_UNBAN_IP'			=> '<strong>Interdicție IP eliminată</strong><br />» %s',
+	'LOG_UNBAN_EMAIL'		=> '<strong>Interdicție e-mail eliminată</strong><br />» %s',
 
 	'LOG_BBCODE_ADD'		=> '<strong>CodBB nou adăugat</strong><br />» %s',
 	'LOG_BBCODE_EDIT'		=> '<strong>CodBB modificat</strong><br />» %s',
@@ -488,11 +488,11 @@ $lang = array_merge($lang, array(
 	'LOG_BOT_DELETE'	=> '<strong>Bot şters</strong><br />» %s',
 	'LOG_BOT_UPDATED'	=> '<strong>Bot existent actualizat</strong><br />» %s',
 
-	'LOG_CLEAR_ADMIN'		=> '<strong>Log admin şters</strong>',
-	'LOG_CLEAR_CRITICAL'	=> '<strong>Log erori şters</strong>',
-	'LOG_CLEAR_MOD'			=> '<strong>Log moderator şters</strong>',
-	'LOG_CLEAR_USER'		=> '<strong>Log utilizator şters</strong><br />» %s',
-	'LOG_CLEAR_USERS'		=> '<strong>Loguri utilizator şterse</strong>',
+	'LOG_CLEAR_ADMIN'		=> '<strong>Jurnal admin şters</strong>',
+	'LOG_CLEAR_CRITICAL'	=> '<strong>Jurnal erori şters</strong>',
+	'LOG_CLEAR_MOD'			=> '<strong>Jurnal moderator şters</strong>',
+	'LOG_CLEAR_USER'		=> '<strong>Jurnal utilizator şters</strong><br />» %s',
+	'LOG_CLEAR_USERS'		=> '<strong>Jurnale utilizator şterse</strong>',
 
 	'LOG_CONFIG_ATTACH'			=> '<strong>Schimbările setărilor fişierelor ataşate</strong>',
 	'LOG_CONFIG_AUTH'			=> '<strong>Schimbările setărilor de autentificare</strong>',
@@ -514,26 +514,26 @@ $lang = array_merge($lang, array(
 
 	'LOG_APPROVE_TOPIC'			=> '<strong>Subiect aprobat</strong><br />» %s',
 	'LOG_BUMP_TOPIC'			=> '<strong>Subiectul uitlizatorului adus în atenţie</strong><br />» %s',
-	'LOG_DELETE_POST'			=> '<strong>Mesaj şters</strong><br />» %s',
+	'LOG_DELETE_POST'			=> '<strong>Mesaj șters „%1$s” scris de</strong><br />» %2$s',
 	'LOG_DELETE_SHADOW_TOPIC'   => '<strong>Subiect umbră şters</strong><br />» %s',
-  'LOG_DELETE_TOPIC'         => '<strong>Subiect şters</strong><br />» %s',
-  'LOG_FORK'               => '<strong>Subiect copiat</strong><br />» din %s',
-  'LOG_LOCK'               => '<strong>Subiect închis</strong><br />» %s',
-  'LOG_LOCK_POST'            => '<strong>Mesaj închis</strong><br />» %s',
-  'LOG_MERGE'               => '<strong>Mesaje unite</strong> în subiectul<br />» %s',
-  'LOG_MOVE'               => '<strong>Subiect mutat</strong><br />» din %1$s în %2$s',
-  'LOG_PM_REPORT_CLOSED'		=> '<strong>Raport Mesaj privat închis</strong><br />» %s',
-	'LOG_PM_REPORT_DELETED'		=> '<strong>Raport Mesaj privat şters</strong><br />» %s',
+	'LOG_DELETE_TOPIC'          => '<strong>Subiect șters „%1$s” scris de</strong><br />» %2$s',
+	'LOG_FORK'                  => '<strong>Subiect copiat</strong><br />» din %s',
+	'LOG_LOCK'                  => '<strong>Subiect închis</strong><br />» %s',
+	'LOG_LOCK_POST'             => '<strong>Mesaj închis</strong><br />» %s',
+	'LOG_MERGE'                 => '<strong>Mesaje unite</strong> în subiectul<br />» %s',
+	'LOG_MOVE'                  => '<strong>Subiect mutat</strong><br />» din %1$s în %2$s',
+	'LOG_PM_REPORT_CLOSED'		=> '<strong>Raport mesaj privat închis</strong><br />» %s',
+	'LOG_PM_REPORT_DELETED'		=> '<strong>Raport mesaj privat şters</strong><br />» %s',
 	'LOG_POST_APPROVED'			=> '<strong>Mesaj aprobat</strong><br />» %s',
-	'LOG_POST_DISAPPROVED'		=> '<strong>Mesaj neaprobat “%1$s” din următorul motiv</strong><br />» %2$s',
-	'LOG_POST_EDITED'			=> '<strong>Mesaj modificat “%1$s” de către</strong><br />» %2$s',
+	'LOG_POST_DISAPPROVED'		=> '<strong>Mesaj neaprobat „%1$s” din următorul motiv</strong><br />» %2$s',
+	'LOG_POST_EDITED'			=> '<strong>Mesaj modificat „%1$s” de către</strong><br />» %2$s',
 	'LOG_REPORT_CLOSED'			=> '<strong>Raport închis</strong><br />» %s',
 	'LOG_REPORT_DELETED'		=> '<strong>Raport şters</strong><br />» %s',
 	'LOG_SPLIT_DESTINATION'		=> '<strong>Mesajele împărţite mutate</strong><br />» la %s',
 	'LOG_SPLIT_SOURCE'			=> '<strong>Împarte mesaje</strong><br />» de la %s',
 
 	'LOG_TOPIC_APPROVED'		=> '<strong>Subiect aprobat</strong><br />» %s',
-	'LOG_TOPIC_DISAPPROVED'		=> '<strong>Subiect neaprobat “%1$s” din următorul motiv</strong><br />%2$s',
+	'LOG_TOPIC_DISAPPROVED'		=> '<strong>Subiect neaprobat „%1$s” din următorul motiv</strong><br />%2$s',
 	'LOG_TOPIC_RESYNC'			=> '<strong>Contoare subiect resincronizate</strong><br />» %s',
 	'LOG_TOPIC_TYPE_CHANGED'	=> '<strong>Tipul schimbat al subiectului</strong><br />» %s',
 	'LOG_UNLOCK'				=> '<strong>Subiect deschis</strong><br />» %s',
@@ -571,7 +571,7 @@ $lang = array_merge($lang, array(
 	'LOG_GENERAL_ERROR'	=> '<strong>A fost întâlnită o eroare generală</strong>: %1$s <br />» %2$s',
 
 	'LOG_GROUP_CREATED'		=> '<strong>Grup nou de utilizatori creat</strong><br />» %s',
-	'LOG_GROUP_DEFAULTS'	=> '<strong>Grup “%1$s” făcut iniţial pentru membri</strong><br />» %s',
+	'LOG_GROUP_DEFAULTS'	=> '<strong>Grup „%1$s” făcut iniţial pentru membri</strong><br />» %s',
 	'LOG_GROUP_DELETE'		=> '<strong>Grup de utilizatori şters</strong><br />» %s',
 	'LOG_GROUP_DEMOTED'		=> '<strong>Lideri retrogradaţi în grupurile de utilizatori</strong> %1$s<br />» %2$s',
 	'LOG_GROUP_PROMOTED'	=> '<strong>Membri promovaţi ca lideri în grupurile de utilizatori</strong> %1$s<br />» %2$s',
@@ -581,7 +581,7 @@ $lang = array_merge($lang, array(
 	
 	'LOG_USERS_ADDED'		=> '<strong>Membri noi adăugaţi în grupurile de utilizatori</strong> %1$s<br />» %2$s',
 	'LOG_USERS_APPROVED'	=> '<strong>Utilizatorii aprobaţi în grupul</strong> %1$s<br />» %2$s',
-	'LOG_USERS_PENDING'		=> '<strong>Utilizatorii ce au cerut să adere la grupul “%1$s” şi care aşteaptă aprobarea</strong><br />» %2$s',
+	'LOG_USERS_PENDING'		=> '<strong>Utilizatorii ce au cerut să adere la grupul „%1$s” şi care aşteaptă aprobarea</strong><br />» %2$s',
 
 	'LOG_IMAGE_GENERATION_ERROR'	=> '<strong>Eroare la crearea imaginii</strong><br />» Eroare în %1$s la linia %2$s: %3$s',
 
@@ -591,8 +591,8 @@ $lang = array_merge($lang, array(
 	'LOG_IMAGESET_EDIT_DETAILS'  	=> '<strong>Detaliile setului de imagini modificate</strong><br />» %s',
 	'LOG_IMAGESET_EDIT'		    	=> '<strong>Set de imagini modificat</strong><br />» %s',
 	'LOG_IMAGESET_EXPORT'		    => '<strong>Set de imagini exportat</strong><br />» %s',
-	'LOG_IMAGESET_LANG_MISSING'		=> '<strong>Setul de imagini nu poate găsi localizarea “%2$s”</strong><br />» %1$s',
-	'LOG_IMAGESET_LANG_REFRESHED'	=> '<strong>Localizarea “%2$s” a setului de imagini reîmprospătată</strong><br />» %1$s',
+	'LOG_IMAGESET_LANG_MISSING'		=> '<strong>Setul de imagini nu poate găsi localizarea „%2$s”</strong><br />» %1$s',
+	'LOG_IMAGESET_LANG_REFRESHED'	=> '<strong>Localizarea „%2$s” a setului de imagini reîmprospătată</strong><br />» %1$s',
 	'LOG_IMAGESET_REFRESHED'     	=> '<strong>Set de imagini reîmprospătat</strong><br />» %s',
 
 	'LOG_INACTIVE_ACTIVATE'	=> '<strong>Utilizatori inactivi activaţi</strong><br />» %s',
@@ -601,7 +601,7 @@ $lang = array_merge($lang, array(
 	'LOG_INSTALL_CONVERTED'	=> '<strong>Covertit de la %1$s la phpBB %2$s</strong>',
 	'LOG_INSTALL_INSTALLED'	=> '<strong>phpBB instalat %s</strong>',
 
-	'LOG_IP_BROWSER_FORWARDED_CHECK'	=> '<strong>IP sesiune/browser/verificare eşuată X_FORWARDED_FOR</strong><br />»IP utilizator “<em>%1$s</em>” verificat împotriva sesiunii IP “<em>%2$s</em>”, stringul browser-ului utilizatorului “<em>%3$s</em>” verificat împotriva stringului de sesiune a browser-ului “<em>%4$s</em>” şi stringul X_FORWARDED_FOR “<em>%5$s</em>” al utilizatorului verificat împotriva stringului de sesiune X_FORWARDED_FOR “<em>%6$s</em>”.',
+	'LOG_IP_BROWSER_FORWARDED_CHECK'	=> '<strong>IP sesiune/browser/verificare eşuată X_FORWARDED_FOR</strong><br />»IP utilizator „<em>%1$s</em>” verificat împotriva sesiunii IP „<em>%2$s</em>”, stringul browser-ului utilizatorului „<em>%3$s</em>” verificat împotriva stringului de sesiune a browser-ului „<em>%4$s</em>” şi stringul X_FORWARDED_FOR „<em>%5$s</em>” al utilizatorului verificat împotriva stringului de sesiune X_FORWARDED_FOR „<em>%6$s</em>”.',
 
 	'LOG_JAB_CHANGED'			=> '<strong>Cont Jabber schimbat</strong>',
 	'LOG_JAB_PASSCHG'			=> '<strong>Parola Jabber schimbată</strong>',
@@ -616,7 +616,7 @@ $lang = array_merge($lang, array(
 
 	'LOG_MASS_EMAIL'		=> '<strong>E-mail în masă trimis</strong><br />» %s',
 
-	'LOG_MCP_CHANGE_POSTER'	=> '<strong>Autor în subiect schimbat “%1$s”</strong><br />» din %2$s în %3$s',
+	'LOG_MCP_CHANGE_POSTER'	=> '<strong>Autor în subiect schimbat „%1$s”</strong><br />» din %2$s în %3$s',
 
 	'LOG_MODULE_DISABLE'	=> '<strong>Modul dezactivat</strong><br />» %s',
 	'LOG_MODULE_ENABLE'		=> '<strong>Modul activat</strong><br />» %s',
@@ -661,7 +661,7 @@ $lang = array_merge($lang, array(
 	'LOG_REASON_ADDED'		=> '<strong>Motiv raport/negare adăugat</strong><br />» %s',
 	'LOG_REASON_REMOVED'	=> '<strong>Motiv raport/negare şters</strong><br />» %s',
 	'LOG_REASON_UPDATED'	=> '<strong>Motiv report/negare actualizat</strong><br />» %s',
-	'LOG_REFERER_INVALID' => '<strong>Validare eşuată a Referer-ului</strong><br />»Referer a fost “<em>%1$s</em>”. Cererea a fost respinsă şi sesiunea închisă.',
+	'LOG_REFERER_INVALID' => '<strong>Validare eşuată a Referer-ului</strong><br />»Referer a fost „<em>%1$s</em>”. Cererea a fost respinsă şi sesiunea închisă.',
 
 	'LOG_RESET_DATE'			=> '<strong>Dată de start pentru forum resetată</strong>',
 	'LOG_RESET_ONLINE'			=> '<strong>Contorul cu majoritatea utilizatorilor online resetat</strong>',
@@ -698,9 +698,9 @@ $lang = array_merge($lang, array(
 	'LOG_UPDATE_PHPBB'		=> '<strong>phpBB actualizat de la versiunea %1$s la versiunea %2$s</strong>',
 
 	'LOG_USER_ACTIVE'		=> '<strong>Utilizator activat</strong><br />» %s',
-	'LOG_USER_BAN_USER'		=> '<strong>Utilizator banat prin management utilizatori</strong> pentru motivul “<em>%1$s</em>”<br />» %2$s',
-	'LOG_USER_BAN_IP'		=> '<strong>IP banat prin management utilizatori</strong> pentru motivul “<em>%1$s</em>”<br />» %2$s',
-	'LOG_USER_BAN_EMAIL'	=> '<strong>E-mail banat prin management utilizatori</strong> pentru motivul “<em>%1$s</em>”<br />» %2$s',
+	'LOG_USER_BAN_USER'		=> '<strong>Utilizator interzis prin management utilizatori</strong> pentru motivul „<em>%1$s</em>”<br />» %2$s',
+	'LOG_USER_BAN_IP'		=> '<strong>IP interzis prin management utilizatori</strong> pentru motivul „<em>%1$s</em>”<br />» %2$s',
+	'LOG_USER_BAN_EMAIL'	=> '<strong>E-mail interzis prin management utilizatori</strong> pentru motivul „<em>%1$s</em>”<br />» %2$s',
 	'LOG_USER_DELETED'		=> '<strong>Utilizator şters</strong><br />» %s',
 	'LOG_USER_DEL_ATTACH'	=> '<strong>Toate fişierele ataşate scoase de către utilizatorul</strong><br />» %s',
 	'LOG_USER_DEL_AVATAR'	=> '<strong>Avatar utilizator şters</strong><br />» %s',
@@ -708,12 +708,12 @@ $lang = array_merge($lang, array(
 	'LOG_USER_DEL_POSTS'	=> '<strong>Toate mesajele şterse de către utilizatorul</strong><br />» %s',
 	'LOG_USER_DEL_SIG'		=> '<strong>Semnătură utilizator ştearsă</strong><br />» %s',
 	'LOG_USER_INACTIVE'		=> '<strong>Utilizator dezactivat</strong><br />» %s',
-	'LOG_USER_MOVE_POSTS'	=> '<strong>Mesajele utilizatorului mutate</strong><br />» mesaje de către “%1$s” în forumul “%2$s”',
+	'LOG_USER_MOVE_POSTS'	=> '<strong>Mesajele utilizatorului mutate</strong><br />» mesaje de către „%1$s” în forumul „%2$s”',
 	'LOG_USER_NEW_PASSWORD'	=> '<strong>Parolă utilizator schimbată</strong><br />» %s',
 	'LOG_USER_REACTIVATE'	=> '<strong>Cont utilizator forţat pentru reactivare</strong><br />» %s',
 	'LOG_USER_REMOVED_NR'	=> '<strong>Marcaj de utilizator nou şters pentru utilizatorul</strong><br />» %s',
-	'LOG_USER_UPDATE_EMAIL'	=> '<strong>E-mail utilizator “%1$s” schimbat</strong><br />» din “%2$s” în “%3$s”',
-	'LOG_USER_UPDATE_NAME'	=> '<strong>Nume utilizator schimbat</strong><br />» din “%1$s” în “%2$s”',
+	'LOG_USER_UPDATE_EMAIL'	=> '<strong>E-mail utilizator „%1$s” schimbat</strong><br />» din „%2$s” în „%3$s”',
+	'LOG_USER_UPDATE_NAME'	=> '<strong>Nume utilizator schimbat</strong><br />» din „%1$s” în „%2$s”',
 	'LOG_USER_USER_UPDATE'	=> '<strong>Detalii utilizator actualizate</strong><br />» %s',
 
 	'LOG_USER_ACTIVE_USER'		=> '<strong>Cont utilzator activat</strong>',
@@ -723,7 +723,7 @@ $lang = array_merge($lang, array(
 	'LOG_USER_GENERAL'			=> '<strong>Intrare adăugată:</strong><br />» %s',
 	'LOG_USER_INACTIVE_USER'	=> '<strong>Cont utilizator dezactivat</strong>',
 	'LOG_USER_LOCK'				=> '<strong>Subiect utilizator blocat</strong><br />» %s',
-	'LOG_USER_MOVE_POSTS_USER'	=> '<strong>Toate mesajele mutate în forumul</strong>',
+	'LOG_USER_MOVE_POSTS_USER'	=> '<strong>Toate mesajele mutate în forumul</strong>» %s',
 	'LOG_USER_REACTIVATE_USER'	=> '<strong>Cont utilizator forţat pentru reactivare</strong>',
 	'LOG_USER_UNLOCK'			=> '<strong>Utilizatorul şi-a deblocat propriul subiect</strong><br />» %s',
 	'LOG_USER_WARNING'			=> '<strong>Avertisment utilizator</strong><br />» %s',
@@ -743,6 +743,4 @@ $lang = array_merge($lang, array(
 	'LOG_WORD_EDIT'			=> '<strong>Cuvânt restricţionat modificat</strong><br />» %s',
 ));
 
-$lang['LOG_TOPIC_DELETED'] = $lang['LOG_DELETE_TOPIC'];
-
 ?>
\ No newline at end of file
