@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	
 		<br />
 
-		<p>Pentru informaţii suplimentare legate de configurarea şi administrarea permisiunilor forumului phpBB3 propriu, vă rugăm să vizitaţi <a href="http://www.phpbb.com/support/documentation/3.0/quickstart/quick_permissions.html">Capitolul 1.5 al Ghidului nostru de Start Rapid</a>.</p>
+		<p>Pentru informaţii suplimentare legate de configurarea şi administrarea permisiunilor forumului phpBB3 propriu, vă rugăm să vizitaţi <a href="https://www.phpbb.com/support/documentation/3.0/quickstart/quick_permissions.html">Capitolul 1.5 al Ghidului nostru de Start Rapid</a>.</p>
 	',
 
 	'ACL_NEVER'				=> 'Niciodată',
@@ -137,7 +137,7 @@ $lang = array_merge($lang, array(
 
 	'NO_AUTH_SETTING_FOUND'		=> 'Configurările permisiunilor nu sunt definite.',
 	'NO_ROLE_ASSIGNED'			=> 'Niciun rol atribuit…',
-	'NO_ROLE_ASSIGNED_EXPLAIN'	=> 'Alocând acest rol nu va schimba permisiunile din dreapta. Dacă vreţi să eliminaţi toate permisiunile ar trebui să foloseiţi legătura “Toate <samp>NU</samp>” .',
+	'NO_ROLE_ASSIGNED_EXPLAIN'	=> 'Alocând acest rol nu va schimba permisiunile din dreapta. Dacă vreţi să eliminaţi toate permisiunile ar trebui să foloseiţi legătura „Toate <samp>NU</samp>” .',
 	'NO_ROLE_AVAILABLE'			=> 'Niciun rol nu este disponibil',
 	'NO_ROLE_NAME_SPECIFIED'	=> 'Daţi un nume rolului.',
 	'NO_ROLE_SELECTED'			=> 'Rolul nu poate fi găsit.',
