@@ -284,9 +284,9 @@ $lang = array_merge($lang, array(
 	'INSTALLED_STYLE'			=> 'Stiluri instalate',
 	'INSTALLED_TEMPLATE'		=> 'Şabloane instalate',
 	'INSTALLED_THEME'			=> 'Teme instalate',
-	'KEEP_IMAGESET'				=> 'Păstrare set imagini “%s”',
-	'KEEP_TEMPLATE'				=> 'Păstrare șablon “%s”',
-	'KEEP_THEME'				=> 'Păstrare temă “%s”',
+	'KEEP_IMAGESET'				=> 'Păstrare set imagini „%s”',
+	'KEEP_TEMPLATE'				=> 'Păstrare șablon „%s”',
+	'KEEP_THEME'				=> 'Păstrare temă „%s”',
 
 	'LINE_SPACING'				=> 'Spaţiu între linii',
 	'LOCALISED_IMAGES'			=> 'Localizat',
@@ -323,7 +323,7 @@ $lang = array_merge($lang, array(
 	'REPLACE_TEMPLATE_EXPLAIN'	=> 'Acest set şablon îl va înlocui pe cel îl ştergeţi în orice stil care îl foloseşte.',
 	'REPLACE_THEME'				=> 'Înlocuieşte tema cu',
 	'REPLACE_THEME_EXPLAIN'		=> 'Această temă o va înlocui pe cea care o ştergeţi în orice stil care o foloseşte.',
-	'REPLACE_WITH_OPTION'		=> 'Înlocuieşte cu “%s”',
+	'REPLACE_WITH_OPTION'		=> 'Înlocuieşte cu „%s”',
 	'REQUIRES_IMAGESET'			=> 'Acest stil necesită ca setul de imagini %s să fie instalat.',
 	'REQUIRES_TEMPLATE'			=> 'Acest stil necesită ca şablonul %s să fie instalat.',
 	'REQUIRES_THEME'			=> 'Acest stil necesită ca tema %s să fie instalată.',
