@@ -36,7 +36,7 @@ if (empty($lang) || !is_array($lang))
 // in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
 //
 // Some characters you may want to copy&paste:
-// ’ » “ ” …
+// ’ » „ ” …
 //
 
 $lang = array_merge($lang, array(
@@ -88,9 +88,10 @@ $lang = array_merge($lang, array(
     'AVATAR_PARTIAL_UPLOAD'         => 'Fişierul specificat a fost încărcat doar parţial.',
     'AVATAR_PHP_SIZE_NA'            => 'Dimensiunea fişierului avatar este prea mare.<br />Dimensiunea maximă permisă setată în php.ini nu a putut fi determinată.',
     'AVATAR_PHP_SIZE_OVERRUN'       => 'Dimensiunea fişierului avatar este prea mare. Dimensiunea maximă permisă pentru încărcare este de %1$d %2$s.<br />Ţineţi minte că aceasta este setată în php.ini şi nu poate fi suprascrisă.',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'	=> 'Avatarul specificat nu poate fi încărcat deoarece cererea a expirat.',
     'AVATAR_URL_INVALID'            => 'URL-ul specificat este invalid.',
     'AVATAR_URL_NOT_FOUND'          => 'Fişierul specificat nu a putut fi găsit.',
-    'AVATAR_WRONG_FILESIZE'         => 'Dimensiunea fişierului avatar trebuie să fie între 0 şi %1d %2s.',
+    'AVATAR_WRONG_FILESIZE'         => 'Dimensiunea fişierului avatar trebuie să fie între 0 şi %1$d %2$s.',
     'AVATAR_WRONG_SIZE'             => 'Avatarul trimis este de %5$d pixeli lungime şi %6$d pixeli înălţime. Avatarurile trebuie să fie de cel puţin %1$d pixeli lungime şi %2$d pixeli înălţime, dar nu mai mari de %3$d pixeli lungime şi %4$d pixeli înălţime.',
 
     'BACK_TO_TOP'           => 'Sus',
@@ -160,6 +161,7 @@ $lang = array_merge($lang, array(
     'EDIT_POST'                         => 'Modifică mesaj',
     'EMAIL'                             => 'E-mail',  // Short form for EMAIL_ADDRESS
     'EMAIL_ADDRESS'                     => 'Adresă de e-mail',
+	'EMAIL_INVALID_EMAIL'				=> 'Adresa de e-mail introdusă este invalidă.',
     'EMAIL_SMTP_ERROR_RESPONSE'         => 'Probleme în trimiterea e-mail-ului la <strong>Linia %1$s</strong>. Răspuns: %2$s.',
     'EMPTY_SUBJECT'                     => 'Trebuie să specificaţi un subiect când scrieţi un subiect nou.',
     'EMPTY_MESSAGE_SUBJECT'             => 'Trebuie să specificaţi un subiect când compuneţi un mesaj nou.',
@@ -291,7 +293,6 @@ $lang = array_merge($lang, array(
 
     'KB'                    => 'KB',
     'KIB'                   => 'KiB',
-    'KNOWLEDGE_BASE'        => 'Catalog articole',
 
     'LAST_POST'                         => 'Ultimul mesaj',
     'LAST_UPDATED'                      => 'Ultima actualizare',
@@ -318,8 +319,8 @@ $lang = array_merge($lang, array(
     'LOGIN_VIEWFORUM'                   => 'Necesită să fiţi înregistrat şi autentificat pentru a putea vizualiza acest forum.',
     'LOGIN_EXPLAIN_EDIT'                => 'Pentru a putea modifica mesajele din acest forum, trebuie să vă înregistraţi şi să vă autentificaţi.',
     'LOGIN_EXPLAIN_VIEWONLINE'          => 'Pentru a putea vizualiza lista cu cei care sunt online, trebuie să vă înregistraţi şi să vă autentificaţi.',
-    'LOGOUT'							=> 'Ieşire',
-	'LOGOUT_USER'						=> 'Ieşire [ %s ]',
+    'LOGOUT'							=> 'Deconectare',
+	'LOGOUT_USER'						=> 'Deconectare [ %s ]',
 	'LOG_ME_IN'							=> 'Autentifică-mă automat la fiecare vizită',
 
     'MARK'                  => 'Marchează',
@@ -341,6 +342,9 @@ $lang = array_merge($lang, array(
     'MODERATE'              => 'Moderează',
     'MODERATOR'             => 'Moderator',
     'MODERATORS'            => 'Moderatori',
+	'MODULE_NOT_ACCESS'		=> 'Modulul nu este accesibil',
+ 	'MODULE_NOT_FIND'		=> 'Nu pot găsi modulul %s',
+ 	'MODULE_FILE_INCORRECT_CLASS'	=> 'Fișierul modulului %s nu conține clasa corectă [%s]',
     'MONTH'                 => 'Lună',
     'MOVE'                  => 'Mută',
     'MSNM'                  => 'MSNM/WLM',  
@@ -391,6 +395,7 @@ $lang = array_merge($lang, array(
     'NO_POSTS_TIME_FRAME'       => 'Nu există niciun mesaj în interiorul acestui subiect pentru perioada de timp selectată.',
     'NO_FEED_ENABLED'			=> 'Fluxurile nu sunt disponibile pentru acest forum.',
 	'NO_FEED'					=> 'Fluxul solicitat nu este disponibil.',
+	'NO_STYLE_DATA'				=> 'Nu au putut fi obținute datele stilului',
     'NO_SUBJECT'                => 'Niciun subiect specificat',                 // Used for posts having no subject defined but displayed within management pages.
     'NO_SUCH_SEARCH_MODULE'     => 'Backend-ul de căutare specificat nu există.',
     'NO_SUPPORTED_AUTH_METHODS' => 'Nu există nicio metodă de autentificare.',
@@ -567,9 +572,11 @@ $lang = array_merge($lang, array(
     'SUBJECT'                   => 'Subiect',
     'SUBMIT'                    => 'Trimite',
 
+	'TB'				=> 'TB',
     'TERMS_USE'         => 'Termeni de utilizare',
     'TEST_CONNECTION'   => 'Testează conexiunea',
     'THE_TEAM'          => 'Echipa',
+	'TIB'				=> 'TiB',
     'TIME'              => 'Data',
     'TOO_LARGE'                  => 'Valoarea specificată este prea mare.',
     'TOO_LARGE_MAX_RECIPIENTS'      => 'Valoarea introdusă pentru setarea <strong>Numărul maxim permis de destinatari pentru fiecare mesaj privat</strong> este prea mare.',
@@ -633,7 +640,7 @@ $lang = array_merge($lang, array(
     'TOTAL_LOGS'        => '%d loguri',
     'TOTAL_NO_PM'       => '0 mesaje private în total',
     'TOTAL_PM'          => '1 mesaj privat în total',
-    'TOTAL_PMS'         => '$d mesaje private în total',
+    'TOTAL_PMS'         => '%d mesaje private în total',
     'TOTAL_POSTS'       => 'Total mesaje',
     'TOTAL_POSTS_OTHER' => 'Total mesaje <strong>%d</strong>',
     'TOTAL_POSTS_ZERO'  => 'Total mesaje <strong>0</strong>',
@@ -644,7 +651,7 @@ $lang = array_merge($lang, array(
     'TOTAL_USERS_ZERO'  => 'Total membri <strong>0</strong>',
     'TRACKED_PHP_ERROR' => 'Erori PHP depistate: %s',
 
-    'UNABLE_GET_IMAGE_SIZE' => 'Nu a fost posibilă determinarea dimensiunilor imaginii.',
+    'UNABLE_GET_IMAGE_SIZE' => 'Nu a fost posibilă determinarea dimensiunilor imaginii. Vă rugăm să verificați dacă adresa URL este corectă.',
     'UNABLE_TO_DELIVER_FILE'=> 'Nu s-a putut trimite fişierul.',
     'UNKNOWN_BROWSER'       => 'Browser necunoscut',
     'UNMARK_ALL'            => 'Deselectează toate',
@@ -654,9 +661,9 @@ $lang = array_merge($lang, array(
     'UNREAD_POST'         => 'Mesaj necitit',
     'UNREAD_POSTS'         => 'Mesaje necitite',
 	'UNWATCH_FORUM_CONFIRM'		=> 'Sunteți sigur că doriți să vă dezabonați de la acest forum?',
-	'UNWATCH_FORUM_DETAILED'	=> 'Sunteți sigur că doriți să vă dezabonați de la forumul “%s”?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Sunteți sigur că doriți să vă dezabonați de la forumul „%s”?',
 	'UNWATCH_TOPIC_CONFIRM'		=> 'Sunteți sigur că doriți să vă dezabonați de la acest subiect?',
-	'UNWATCH_TOPIC_DETAILED'	=> 'Sunteți sigur că doriți să vă dezabonați de la subiectul “%s”?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Sunteți sigur că doriți să vă dezabonați de la subiectul „%s”?',
     'UNWATCHED_FORUMS'      => 'Nu mai sunteţi abonat la forumurile selectate.',
     'UNWATCHED_TOPICS'      => 'Nu mai sunteţi abonat subiectele selectate.',
     'UNWATCHED_FORUMS_TOPICS'   => 'Nu mai sunteţi abonat la intrările selectate.',
@@ -705,14 +712,15 @@ $lang = array_merge($lang, array(
     'WARNINGS'          => 'Avertismente',
     'WARN_USER'         => 'Avertizează utilizator',
 	'WATCH_FORUM_CONFIRM'	=> 'Sunteți sigur că doriți să vă abonați la acest forum?',
-	'WATCH_FORUM_DETAILED'	=> 'Sunteți sigur că doriți să vă abonați la forumul “%s”?',
+	'WATCH_FORUM_DETAILED'	=> 'Sunteți sigur că doriți să vă abonați la forumul „%s”?',
 	'WATCH_TOPIC_CONFIRM'	=> 'Sunteți sigur că doriți să vă abonați la acest subiect?',
-	'WATCH_TOPIC_DETAILED'	=> 'Sunteți sigur că doriți să vă abonați la subiectul “%s”?',
+	'WATCH_TOPIC_DETAILED'	=> 'Sunteți sigur că doriți să vă abonați la subiectul „%s”?',
     'WELCOME_SUBJECT'   => 'Bine aţi venit în forumurile %s',
     'WEBSITE'           => 'Site web',
     'WHOIS'             => 'Cine este',
     'WHO_IS_ONLINE'     => 'Cine este conectat',
     'WRONG_PASSWORD'    => 'Aţi introdus o parolă incorectă.',
+	'WRONG_DATA_COLOUR'			=> 'Valoarea culorii introduse este invalidă.',
 
     'WRONG_DATA_ICQ'            => 'Numărul introdus nu este un număr ICQ valid.',
     'WRONG_DATA_JABBER'         => 'Numele introdus nu este un nume de cont Jabber valid.',
